@@ -11,6 +11,7 @@ from django.views.generic import TemplateView
 from ...decorators import permission_required
 from ...forms import ImprintTranslationForm
 from ...models import Language, ImprintPage
+from ...constants import status
 
 logger = logging.getLogger(__name__)
 
@@ -29,6 +30,7 @@ class ImprintSideBySideView(TemplateView):
         "current_menu_item": "imprint",
         "WEBAPP_URL": settings.WEBAPP_URL,
         "IMPRINT_SLUG": settings.IMPRINT_SLUG,
+        "PUBLIC": status.PUBLIC,
     }
 
     def get(self, request, *args, **kwargs):
