@@ -87,8 +87,18 @@ class PageSideBySideView(TemplateView, PageContextMixin):
                 },
             )
 
+        disabled = False
+        # Make form disabled if user has no permission to edit the page
+        if not request.user.has_perm("cms.change_page_object", page):
+            disabled = True
+            messages.warning(
+                request,
+                _("You don't have the permission to edit this page."),
+            )
+
         page_translation_form = PageTranslationForm(
             instance=target_page_translation,
+            disabled=disabled,
         )
 
         return render(
@@ -190,9 +200,9 @@ class PageSideBySideView(TemplateView, PageContextMixin):
         elif not page_translation_form.has_changed():
             # Add "no changes" messages
             messages.info(request, _("No changes made"))
-        elif (
-            not request.user.has_perm("cms.publish_page_object", page)
-            and page_translation_form.cleaned_data.get("status") == status.PUBLIC
+        elif not request.user.has_perm("cms.publish_page_object", page) and (
+            page_translation_form.cleaned_data.get("status")
+            in [status.DRAFT, status.PUBLIC]
         ):
             # Raise PermissionDenied if user wants to publish page but doesn't have the permission
             raise PermissionDenied(
